# Examples

```{toctree}
loading_chess_data
using_plot_slice
animations
using_scissors
fitting_linecuts
performing_HHL_linecut
working_with_chess_data
fitting_chess_data
extracting_an_order_parameter
using_symmetrizer
extracting_delta_pdf
```
